@@ -74,6 +74,7 @@ class SettingsHolder:
     PUBLISH_TX_FEE = None
     REGISTER_TX_FEE = None
 
+    DATA_DIR_PATH = None
     LEVELDB_PATH = None
     NOTIFICATION_DB_PATH = None
 
@@ -97,6 +98,27 @@ class SettingsHolder:
     # Emit Notify events when smart contract execution failed. Use for debugging purposes only.
     emit_notify_events_on_sc_execution_error = False
 
+    @property
+    def chain_leveldb_path(self):
+        if self.DATA_DIR_PATH:
+            self.check_chain_dir_exists()
+            return os.path.join(self.DATA_DIR_PATH, self.LEVELDB_PATH)
+        return os.path.join(DIR_PROJECT_ROOT, self.LEVELDB_PATH)
+
+    @property
+    def notification_leveldb_path(self):
+        if self.DATA_DIR_PATH:
+            self.check_chain_dir_exists()
+            return os.path.join(self.DATA_DIR_PATH, self.NOTIFICATION_DB_PATH)
+        return os.path.join(DIR_PROJECT_ROOT, self.NOTIFICATION_DB_PATH)
+
+    @property
+    def debug_storage_leveldb_path(self):
+        if self.DATA_DIR_PATH:
+            self.check_chain_dir_exists()
+            return os.path.join(self.DATA_DIR_PATH, self.DEBUG_STORAGE_PATH)
+        return os.path.join(DIR_PROJECT_ROOT, self.DEBUG_STORAGE_PATH)
+
     # Helpers
     @property
     def is_mainnet(self):
@@ -146,7 +168,7 @@ class SettingsHolder:
         self.REGISTER_TX_FEE = fees['RegisterTransaction']
 
         config = data['ApplicationConfiguration']
-        self.LEVELDB_PATH = os.path.join(DIR_PROJECT_ROOT, config['DataDirectoryPath'])
+        self.LEVELDB_PATH = config['DataDirectoryPath']
         self.RPC_PORT = int(config['RPCPort'])
         self.NODE_PORT = int(config['NodePort'])
         self.WS_PORT = config['WsPort']
@@ -164,7 +186,7 @@ class SettingsHolder:
             self.DEBUG_STORAGE_PATH = config['DebugStoragePath']
 
         if 'NotificationDataPath' in config:
-            self.NOTIFICATION_DB_PATH = os.path.join(DIR_PROJECT_ROOT, config['NotificationDataPath'])
+            self.NOTIFICATION_DB_PATH = config['NotificationDataPath']
 
     def setup_mainnet(self):
         """ Load settings from the mainnet JSON config file """
@@ -227,6 +249,20 @@ class SettingsHolder:
         """
         logzero.loglevel(level)
 
+    def check_chain_dir_exists(self):
+        """
+        Checks to make sure there is a directory called ``Chains`` at the root of DATA_DIR_PATH
+        and creates it if it doesn't exist yet
+        """
+        if self.DATA_DIR_PATH is not None:
+            chain_path = os.path.join(self.DATA_DIR_PATH, 'Chains')
+            if not os.path.exists(chain_path):
+                try:
+                    os.makedirs(chain_path)
+                    logzero.logger.info("Created 'Chains' directory at %s " % chain_path)
+                except Exception as e:
+                    logzero.logger.error("Could not create 'Chains' directory at %s %s" % (chain_path, e))
+
     def check_privatenet(self):
         """
         Check if privatenet is running, and if container is same as the current Chains/privnet database.
