@@ -970,6 +970,10 @@ def main():
     parser.add_argument("-v", "--verbose", action="store_true", default=False,
                         help="Show smart-contract events by default")
 
+    # Where to store stuff
+    parser.add_argument("--datadir", action="store",
+                        help="Absolute path to use for database directories")
+
     # Show the neo-python version
     parser.add_argument("--version", action="version",
                         version="neo-python v{version}".format(version=__version__))
@@ -996,8 +1000,11 @@ def main():
     if args.verbose:
         settings.set_log_smart_contract_events(True)
 
+    if args.datadir:
+        settings.DATA_DIR_PATH = args.datadir
+
     # Instantiate the blockchain and subscribe to notifications
-    blockchain = LevelDBBlockchain(settings.LEVELDB_PATH)
+    blockchain = LevelDBBlockchain(settings.chain_leveldb_path)
     Blockchain.RegisterBlockchain(blockchain)
 
     # Try to set up a notification db
